Cross-validation of generalized linear model prediction using multiple imputation - Rubin's rule coefficient-averaging method
.glm.mipred.cmb2.cv(formula, family, dataset, nimp, folds, miop)Formula used by fitting and prediction method
Error distribution also determining the link function used
A data frame containing calibration data
Number of imputations for each observation
Number of folds defined in data
Mice options
A list containing predictions.
predMatrix
of predictions on the scale of the response variable of dimension m
by nimp.
linpredMatrix of predictions on the scale
of the linear predictor of dimension m by nimp.